* This file is a part of NMSSMCALC
* It contains:
* subroutine ismSTU_check: compute STU parameters of the SM
* double precision function ismDZself: compute derivative of Z-selfenergy of the SM
* double precision function ismYself: compute gamma-selfenergy  of the SM
* double precision function ismDYself: compute derivative of Z-selfenergy  of the SM
* double precision function ismZself: compute Z-selfenergy  of the SM
* double precision function ismWself: compute W-selfenergy  of the SM
* double precision function ismDWself: compute derivative of W-selfenergy  of the SM
* subroutine ismSTU_UVcheck: check UV finite of STU parameters of the SM
c last modified by ND 7/2021
c*********************************************************************c
#include "def.h"
      subroutine ismSTU_check()
      implicit none
      integer i,j,gt1,gt2,gt3,gt4

      
      double precision abslambda, abskappa, absAlambda, absAkappa,vs,
     &                 mueff,tanb,beta

      double precision ismZself,ismyself,ismWself,ismyzself,
     &                ismdzself,ismdyself,ismdwself,ismdyzself,
     &                S,T,U
      double precision selfz,selfy,selfw,selfyz,
     &                 dselfz,dselfy,dselfw,dselfyz,selfQQ,self3Q,
     &                 self33,self11,dselfQQ,dself3Q,
     &                 dself33,dself11 
#include "SM.h"

       alfa= e**2/4D0/pi
       MH2=125D0**2
c       print*, "T", (selfw/MW2-selfz/MZ2 ) /alfa,- mt**2*3/16/pi**2/v**2 /alfa
       selfz=ismZself(0D0)
       selfw=ismwself(0D0)
       selfy=ismyself(0D0)
       selfyz=ismyZself(0D0)

       dselfz=(ismZself(MZ2)-ismZself(0D0))/MZ2
       dselfw=(ismwself(MW2)-ismwself(0D0))/MW2
       dselfy=ismdyself(0D0)
       dselfyz=ismdyZself(0D0)

c       selfQQ= selfy/e**2
c       self3Q=(cw*selfyz*sw)/e**2 + (selfy*sw**2)/e**2
       self11=(selfw*sw**2)/e**2
       self33=(cw**2*selfz*sw**2)/e**2 + 
     -    (2*cw*selfyz*sw**3)/e**2 + (selfy*sw**4)/e**2

c       dselfQQ= dselfy/e**2
       dself3Q=(cw*dselfyz*sw)/e**2 + (dselfy*sw**2)/e**2
       dself11=(dselfw*sw**2)/e**2
       dself33=(cw**2*dselfz*sw**2)/e**2 + 
     -    (2*cw*dselfyz*sw**3)/e**2 + (dselfy*sw**4)/e**2


       S= 16*pi*(dself33 -dself3Q)
       T= 4*pi/sw**2/cw**2/MZ2*(self11 -self33)
       U = 16*pi*(dself11 -dself33)
#ifdef detalis
       print*, "=======================SM==========================="
       print*, "Follow definitions in  M. E. Peskin and T. Takeuchi 1992, "
       print*, "T", (selfw/MW2-selfz/MZ2 ) /alfa,- mt**2*3/16/pi**2/v**2 /alfa

       print*, "S",4*sw**2*cw**2*4*pi/e**2 *(dselfz - (cw**2-sw**2)/cw/sw*dselfyz -dselfy)
       print*, "U", 4*sw**2*4*pi/e**2*(dselfw - cw**2*dselfz - sw**2*dselfy- 2*cw*sw*dselfyz)

       print*, "selfz,selfw,selfy,selfyz",selfz,selfw,selfy,selfyz
       print*, "dselfz,dselfw,dselfy,dselfyz",dselfz,dselfw,dselfy,dselfyz
       print*, "S,T,U= ",S,T,U
#endif
      end



c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismDZself(p2)
      implicit none
      integer i,j,gt1,gt2,gt3,gt4
      integer gen3      
      double precision p2,Dself    
#include "SM.h"
      Dself=0D0
       Dself=Dself+(-4*Alfa*Pi*(2*CW2*Finite+6*CW2*
     &  myB0i(bb1,P2,MW2,MW2)-(3*MW2*myB0i(dbb0,P2,MH2,MZ2))/CW2**2+3*
     &  (9*CW2-2*SW2+SW2**2/CW2)*myB0i(dbb00,P2,MW2,MW2)+(3*(10*CW2**2*
     &  myB0i(bb0,P2,MW2,MW2)+3*myB0i(bb1,P2,0D0,0D0)+4*CW2**2*MW2*
     &  myB0i(dbb0,P2,MW2,MW2)+10*CW2**2*P2*myB0i(dbb0,P2,MW2,MW2)-4*
     &  MW2*SW2**2*myB0i(dbb0,P2,MW2,MW2)-6*myB0i(dbb00,P2,0D0,0D0)+2*
     &  myB0i(dbb00,P2,MH2,MZ2)+3*P2*myB0i(dbb1,P2,0D0,0D0)))/(2d0*CW2)+
     &  6*CW2*P2*myB0i(dbb1,P2,MW2,MW2)))/(3d0*SW2)
           do Gen3 = 1,3
       Dself=Dself+(-2*Alfa*Pi*(((9-12*SW2+8*SW2**2)*
     &  myB0i(bb1,P2,MFd2(Gen3),MFd2(Gen3)))/SW2-3*(4-1/SW2-8*SW2)*
     &  myB0i(bb1,P2,MFe2(Gen3),MFe2(Gen3))+((9-24*SW2+32*SW2**2)*
     &  myB0i(bb1,P2,MFu2(Gen3),MFu2(Gen3)))/SW2+(9*MFd2(Gen3)*
     &  myB0i(dbb0,P2,MFd2(Gen3),MFd2(Gen3))+3*MFe2(Gen3)*
     &  myB0i(dbb0,P2,MFe2(Gen3),MFe2(Gen3))+9*MFu2(Gen3)*
     &  myB0i(dbb0,P2,MFu2(Gen3),MFu2(Gen3)))/SW2+6*(4-1/SW2-8*SW2)*
     &  myB0i(dbb00,P2,MFe2(Gen3),MFe2(Gen3))+2*((12-9/SW2-8*SW2)*
     &  myB0i(dbb00,P2,MFd2(Gen3),MFd2(Gen3))+(24-9/SW2-32*SW2)*
     &  myB0i(dbb00,P2,MFu2(Gen3),MFu2(Gen3)))+(P2*((9-12*SW2+8*SW2**2)
     &  *myB0i(dbb1,P2,MFd2(Gen3),MFd2(Gen3))+3*(1-4*SW2+8*SW2**2)*
     &  myB0i(dbb1,P2,MFe2(Gen3),MFe2(Gen3))+(9-24*SW2+32*SW2**2)*
     &  myB0i(dbb1,P2,MFu2(Gen3),MFu2(Gen3))))/SW2))/(3d0*CW2)
           enddo
      ismDZself=Dself*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismYself(p2)
      implicit none
      integer i,j,gt1,gt2,gt3,gt4
      integer gen3      
      double precision p2,self    
#include "SM.h"
      self=0D0
       self=self+(-4*Alfa*Pi*(2*Finite*P2-18*myA0(MW2)+15*P2*
     &  myB0i(bb0,P2,MW2,MW2)+36*myB0i(bb00,P2,MW2,MW2)+6*P2*
     &  myB0i(bb1,P2,MW2,MW2)))/3d0
           do Gen3 = 1,3
       self=self+(-16*Alfa*Pi*(myA0(MFd2(Gen3))+3*myA0(MFe2(Gen3))+4*
     &  myA0(MFu2(Gen3))-2*myB0i(bb00,P2,MFd2(Gen3),MFd2(Gen3))-6*
     &  myB0i(bb00,P2,MFe2(Gen3),MFe2(Gen3))-8*myB0i(bb00,P2,MFu2(Gen3)
     &  ,MFu2(Gen3))+P2*myB0i(bb1,P2,MFd2(Gen3),MFd2(Gen3))+3*P2*
     &  myB0i(bb1,P2,MFe2(Gen3),MFe2(Gen3))+4*P2*
     &  myB0i(bb1,P2,MFu2(Gen3),MFu2(Gen3))))/3d0
           enddo
      ismYself=self*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismDYself(p2)
      implicit none
      integer i,j,gt1,gt2,gt3,gt4
      integer gen3        
      double precision p2,Dself    
#include "SM.h"
      Dself=0D0
       Dself=Dself+(-4*Alfa*Pi*(2*Finite+15*myB0i(bb0,P2,MW2,MW2)+6*
     &  myB0i(bb1,P2,MW2,MW2)+15*P2*myB0i(dbb0,P2,MW2,MW2)+36*
     &  myB0i(dbb00,P2,MW2,MW2)+6*P2*myB0i(dbb1,P2,MW2,MW2)))/3d0
           do Gen3 = 1,3
       Dself=Dself+(-16*Alfa*Pi*(myB0i(bb1,P2,MFd2(Gen3),MFd2(Gen3))+3*
     &  myB0i(bb1,P2,MFe2(Gen3),MFe2(Gen3))+4*myB0i(bb1,P2,MFu2(Gen3)
     &  ,MFu2(Gen3))-2*myB0i(dbb00,P2,MFd2(Gen3),MFd2(Gen3))-6*
     &  myB0i(dbb00,P2,MFe2(Gen3),MFe2(Gen3))-8*
     &  myB0i(dbb00,P2,MFu2(Gen3),MFu2(Gen3))+P2*
     &  myB0i(dbb1,P2,MFd2(Gen3),MFd2(Gen3))+3*P2*
     &  myB0i(dbb1,P2,MFe2(Gen3),MFe2(Gen3))+4*P2*
     &  myB0i(dbb1,P2,MFu2(Gen3),MFu2(Gen3))))/3d0
           enddo
      ismDYself=Dself*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismYZself(p2)
      implicit none
      integer gen3      
      double precision p2,self    
#include "SM.h"
      self=0D0
       self=self+(4*Alfa*Pi*(2*CW2*Finite*P2+(3-18*CW2)*myA0(MW2)+3*(2*
     &  CW2*MW2+5*CW2*P2+2*MW2*SW2)*myB0i(bb0,P2,MW2,MW2)+30*CW2*
     &  myB0i(bb00,P2,MW2,MW2)-6*SW2*myB0i(bb00,P2,MW2,MW2)+6*CW2*P2*
     &  myB0i(bb1,P2,MW2,MW2)))/(3d0*CW*SW)

           do Gen3 = 1,3
       self=self+(-4*Alfa*Pi*((-3+4*SW2)*(myA0(MFd2(Gen3))-2*
     &  myB0i(bb00,P2,MFd2(Gen3),MFd2(Gen3)))+3*(-1+4*SW2)*
     &  (myA0(MFe2(Gen3))-2*myB0i(bb00,P2,MFe2(Gen3),MFe2(Gen3)))+2*(-
     &  3+8*SW2)*(myA0(MFu2(Gen3))-2*myB0i(bb00,P2,MFu2(Gen3)
     &  ,MFu2(Gen3)))+P2*((-3+4*SW2)*myB0i(bb1,P2,MFd2(Gen3),MFd2(Gen3)
     &  )+3*(-1+4*SW2)*myB0i(bb1,P2,MFe2(Gen3),MFe2(Gen3))+2*(-3+8*SW2)
     &  *myB0i(bb1,P2,MFu2(Gen3),MFu2(Gen3)))))/(3d0*CW*SW)
           enddo
      ismYZself=self*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismDYZself(p2)
      implicit none
      integer gen3      
      double precision p2,Dself    
#include "SM.h"
      Dself=0D0
       Dself=Dself+(4*Alfa*Pi*(2*CW2*Finite+15*CW2*
     &  myB0i(bb0,P2,MW2,MW2)+6*CW2*myB0i(bb1,P2,MW2,MW2)+6*CW2*MW2*
     &  myB0i(dbb0,P2,MW2,MW2)+15*CW2*P2*myB0i(dbb0,P2,MW2,MW2)+6*MW2*
     &  SW2*myB0i(dbb0,P2,MW2,MW2)+30*CW2*myB0i(dbb00,P2,MW2,MW2)-6*
     &  SW2*myB0i(dbb00,P2,MW2,MW2)+6*CW2*P2*myB0i(dbb1,P2,MW2,MW2)))
     &  /(3d0*CW*SW)
           do Gen3 = 1,3
       Dself=Dself+(-4*Alfa*Pi*((-3+4*SW2)*myB0i(bb1,P2,MFd2(Gen3)
     &  ,MFd2(Gen3))+3*(-1+4*SW2)*myB0i(bb1,P2,MFe2(Gen3),MFe2(Gen3))+
     &  2*(-3+8*SW2)*myB0i(bb1,P2,MFu2(Gen3),MFu2(Gen3))+2*(3-4*SW2)*
     &  myB0i(dbb00,P2,MFd2(Gen3),MFd2(Gen3))+6*(1-4*SW2)*
     &  myB0i(dbb00,P2,MFe2(Gen3),MFe2(Gen3))+4*(3-8*SW2)*
     &  myB0i(dbb00,P2,MFu2(Gen3),MFu2(Gen3))+P2*((-3+4*SW2)*
     &  myB0i(dbb1,P2,MFd2(Gen3),MFd2(Gen3))+3*(-1+4*SW2)*
     &  myB0i(dbb1,P2,MFe2(Gen3),MFe2(Gen3))+2*(-3+8*SW2)*
     &  myB0i(dbb1,P2,MFu2(Gen3),MFu2(Gen3)))))/(3d0*CW*SW)
           enddo
      ismDYZself=Dself*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismZself(p2)
      implicit none
      integer i,j,gt1,gt2,gt3,gt4
      integer gen3        
      double precision p2,self,faca0,facb0,facb1,facb00
#include "SM.h"
      self=0D0
       faca0=1
       facb0=1
       facb1=1
       facb00=1
       self=self-(Alfa*Pi*(8*CW2*Finite*P2+6*(3-12*CW2-SW2/CW2)*
     &  faca0*myA0(MW2)-(3*(faca0*myA0(MH2)+faca0*myA0(MZ2)))/CW2-(12*MW2*
     &  facb0*myB0i(bb0,P2,MH2,MZ2))/CW2**2+12*(9*CW2-2*SW2+SW2**2/CW2)*
     &  facb00*myB0i(bb00,P2,MW2,MW2)+(6*(2*(CW2**2*(2*MW2+5*P2)-2*MW2*SW2**2)
     &  *facb0*myB0i(bb0,P2,MW2,MW2)-6*facb00*myB0i(bb00,P2,0D0,0D0)+2*
     &  facb00*myB0i(bb00,P2,MH2,MZ2)+3*P2*facb1*myB0i(bb1,P2,0D0,0D0)))/CW2+24*CW2*
     &  P2*facb1*myB0i(bb1,P2,MW2,MW2)))/(3d0*SW2)

c        print*, "selfZ", self*fac/MZ2 /alfa
 
c         print*, "denner",-alfa/4D0/pi* (1/6D0/sw2/cw2*( ( 24*cw2**2+16*cw2-10)*mw2*
c     &           myB0i(bb0,p2,MW2,MW2)-(24*cw2**2-8*cw2+2)*mw2*myB0i(bb0,0D0,MW2,MW2)
c     &         )+
c     &         1/12D0/sw2/cw2*((2*MH2-10*MZ2-p2)*myB0i(bb0,p2,mz2,mh2) 
c     &         -2*mz2*myB0i(bb0,0D0,mz2,mz2) -2*Mh2*myB0i(bb0,0D0,mh2,mh2)
c     &         - 2/3D0*p2 - (mz2-mh2)**2*myb0i(dbb0,0D0,mz2,mh2) ))/MZ2 /alfa
           do Gen3 = 1,3
       self=self+(-2*Alfa*Pi*(((9-12*SW2+8*SW2**2)*myA0(MFd2(Gen3))+(9-
     &  24*SW2+32*SW2**2)*myA0(MFu2(Gen3)))/SW2+(9*MFd2(Gen3)*
     &  myB0i(bb0,P2,MFd2(Gen3),MFd2(Gen3))+3*MFe2(Gen3)*
     &  myB0i(bb0,P2,MFe2(Gen3),MFe2(Gen3))+9*MFu2(Gen3)*
     &  myB0i(bb0,P2,MFu2(Gen3),MFu2(Gen3)))/SW2+(3*(1-4*SW2+8*SW2**2)*
     &  (myA0(MFe2(Gen3))-2*myB0i(bb00,P2,MFe2(Gen3),MFe2(Gen3))))/SW2+
     &  2*((12-9/SW2-8*SW2)*myB0i(bb00,P2,MFd2(Gen3),MFd2(Gen3))+(24-
     &  9/SW2-32*SW2)*myB0i(bb00,P2,MFu2(Gen3),MFu2(Gen3)))+(P2*((9-12*
     &  SW2+8*SW2**2)*myB0i(bb1,P2,MFd2(Gen3),MFd2(Gen3))+3*(1-4*SW2+8*
     &  SW2**2)*myB0i(bb1,P2,MFe2(Gen3),MFe2(Gen3))+(9-24*SW2+32*SW2**
     &  2)*myB0i(bb1,P2,MFu2(Gen3),MFu2(Gen3))))/SW2))/(3d0*CW2)
           enddo
       ismZself=self*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismWself(p2)
      implicit none
      integer gen3      
      double precision p2,self,faca0,facb0,facb1,facb00    
#include "SM.h"
       self=0D0
       faca0=1
       facb0=1
       facb1=1
       facb00=1
       self=self-4*Alfa*Pi*(-((MW2-5*P2)*facb0*myB0i(bb0,P2,0D0,MW2))+8*
     &  facb00*myB0i(bb00,P2,0D0,MW2)+(facb00*myB0i(bb00,P2,MH2,MW2)+(1+8*CW2)*
     & facb00*myB0i(bb00,P2,MW2,MZ2))/SW2+2*P2*facb1*myB0i(bb1,P2,0D0,MW2)-(-8*
     &  Finite*P2+18*faca0*myA0(MW2)+3*(faca0*myA0(MH2)+faca0*myA0(MZ2)+12*CW2*faca0*myA0(MZ2))
     &  +12*MW2*facb0*myB0i(bb0,P2,MH2,MW2)+3*(-4*CW2*(2*MZ2+3*P2)+(4*MW2*
     &  SW2**2)/CW2)*facb0*myB0i(bb0,P2,MW2,MZ2)+24*CW2*P2*
     &  facb1*myB0i(bb1,P2,MW2,MZ2))/(12d0*SW2))
c         print*, "selfW", self*fac/MW2 /alfa


c       print*, -(Alfa*Pi*(8*CW2**2*P2+8*CW2*P2*SW2-3*CW2*myA0(MH2)+6*
c     &  CW2*(-7+4*CW2+4*SW2)*myA0(MW2)-3*CW2*myA0(MZ2)-36*CW2**2*
c     &  myA0(MZ2)-12*CW2*MW2*SW2*myB0i(bb0,P2,0D0,MW2)+60*CW2*P2*SW2*
c     &  myB0i(bb0,P2,0D0,MW2)-12*CW2*MW2*myB0i(bb0,P2,MH2,MW2)+24*CW2**
c     &  2*MZ2*myB0i(bb0,P2,MW2,MZ2)+36*CW2**2*P2*myB0i(bb0,P2,MW2,MZ2)-
c     &  12*MW2*SW2**2*myB0i(bb0,P2,MW2,MZ2)+96*CW2*SW2*
c     &  myB0i(bb00,P2,0D0,MW2)+12*CW2*myB0i(bb00,P2,MH2,MW2)+12*CW2*
c     &  myB0i(bb00,P2,MW2,MZ2)+96*CW2**2*myB0i(bb00,P2,MW2,MZ2)+24*CW2*
c     &  P2*SW2*myB0i(bb1,P2,0D0,MW2)-24*CW2**2*P2*myB0i(bb1,P2,MW2,MZ2)
c     &  ))/(3d0*CW2*SW2)*fac/MW2 /alfa

c       print*, "denner", -alfa/4D0/pi*(2/3d0*(2*MW2*myB0i(bb0,p2,Mw2,0D0)-
c     &           2*mw2*myb0i(bb0,0D0,mw2,mw2) -mw2**2*myb0i(dbb0, p2,mw2,0d0) ) 
c     &          +1/12D0/sw2*((16*cw2+54-10d0/cw2)*MW2*myb0i(bb0,p2,mw2,mz2)
c     &         -(16*cw2+2)*(mw2*myb0i(bb0,0D0,mw2,mw2)+mz2*myb0i(bb0,p2,mz2,mz2))
c     &        -(8*cw2+1)*(mw2-mz2)**2*myb0i(dbb0,p2,mw2,mz2) )
c     &        + 1/12d0/sw2*((2*mh2-10*mw2)*myb0i(bb0,p2,mw2,mh2)
c     &          -2*mw2*myb0i(bb0,0D0,mw2,mw2) -2*mh2*myb0i(bb0,0D0,mh2,mh2)
c     &          - (mw2-mh2)**2*myb0i(dbb0, p2,mw2,mh2) ) )/MW2 /alfa
c         stop
           do Gen3 = 1,3
       self=self+(-4*Alfa*Pi*(3*myA0(MFd2(Gen3))+myA0(MFe2(Gen3))+3*
     &  MFu2(Gen3)*myB0i(bb0,P2,MFd2(Gen3),MFu2(Gen3))-2*
     &  myB0i(bb00,P2,0D0,MFe2(Gen3))-6*myB0i(bb00,P2,MFu2(Gen3)
     &  ,MFd2(Gen3))+P2*myB0i(bb1,P2,0D0,MFe2(Gen3))+3*P2*
     &  myB0i(bb1,P2,MFu2(Gen3),MFd2(Gen3))))/SW2
           enddo
      ismWself=self*fac
      end
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      double precision function ismDWself(p2)
      implicit none
      integer gen3
      double precision p2,Dself
#include "SM.h"
      Dself=0D0
       Dself=Dself-4*Alfa*Pi*(5*myB0i(bb0,P2,0D0,MW2)+2*
     &  myB0i(bb1,P2,0D0,MW2)-(MW2-5*P2)*myB0i(dbb0,P2,0D0,MW2)+8*
     &  myB0i(dbb00,P2,0D0,MW2)+(myB0i(dbb00,P2,MH2,MW2)+(1+8*CW2)*
     &  myB0i(dbb00,P2,MW2,MZ2))/SW2+2*P2*myB0i(dbb1,P2,0D0,MW2)-(-8*
     &  Finite-36*CW2*myB0i(bb0,P2,MW2,MZ2)+24*CW2*
     &  myB0i(bb1,P2,MW2,MZ2)+12*MW2*myB0i(dbb0,P2,MH2,MW2)+3*(-4*CW2*
     &  (2*MZ2+3*P2)+(4*MW2*SW2**2)/CW2)*myB0i(dbb0,P2,MW2,MZ2)+24*CW2*
     &  P2*myB0i(dbb1,P2,MW2,MZ2))/(12d0*SW2))
           do Gen3 = 1,3
       Dself=Dself+(-4*Alfa*Pi*(myB0i(bb1,P2,0D0,MFe2(Gen3))+3*
     &  myB0i(bb1,P2,MFu2(Gen3),MFd2(Gen3))+3*MFu2(Gen3)*
     &  myB0i(dbb0,P2,MFd2(Gen3),MFu2(Gen3))-2*
     &  myB0i(dbb00,P2,0D0,MFe2(Gen3))-6*myB0i(dbb00,P2,MFu2(Gen3)
     &  ,MFd2(Gen3))+P2*myB0i(dbb1,P2,0D0,MFe2(Gen3))+3*P2*
     &  myB0i(dbb1,P2,MFu2(Gen3),MFd2(Gen3))))/SW2
           enddo
      ismDWself=Dself*fac
      end


